aboutsummaryrefslogtreecommitdiff
path: root/test/functional/feature_rbf.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/functional/feature_rbf.py')
-rwxr-xr-xtest/functional/feature_rbf.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/test/functional/feature_rbf.py b/test/functional/feature_rbf.py
index 739b9b9bb9..b660b96935 100755
--- a/test/functional/feature_rbf.py
+++ b/test/functional/feature_rbf.py
@@ -26,15 +26,18 @@ class ReplaceByFeeTest(BitcoinTestFramework):
def set_test_params(self):
self.num_nodes = 2
+ # both nodes disable full-rbf to test BIP125 signaling
self.extra_args = [
[
+ "-mempoolfullrbf=0",
"-limitancestorcount=50",
"-limitancestorsize=101",
"-limitdescendantcount=200",
"-limitdescendantsize=101",
],
# second node has default mempool parameters
[
+ "-mempoolfullrbf=0",
],
]
self.supports_cli = False
@@ -727,4 +730,4 @@ class ReplaceByFeeTest(BitcoinTestFramework):
assert conflicting_tx['txid'] in self.nodes[0].getrawmempool()
if __name__ == '__main__':
- ReplaceByFeeTest().main()
+ ReplaceByFeeTest(__file__).main()
@@ -26,15 +26,18 @@ class ReplaceByFeeTest(BitcoinTestFramework):
"-limitdescendantsize=101",
],
- # second node has default mempool parameters
+ # second node has default mempool parameters, besides mempoolfullrbf being disabled
[